"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    directory_id: str,
    remote_domain_name: str,
    trust_password: str,
    trust_direction: str,
    trust_type: str = None,
    conditional_forwarder_ip_addrs: List = None,
    selective_auth: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    AWS Directory Service for Microsoft Active Directory allows you to configure trust relationships. For example, you can establish a trust between your AWS Managed Microsoft AD directory, and your existing on-premises Microsoft Active Directory. This would allow you to provide users and groups access to resources in either domain, with a single set of credentials. This action initiates the creation of the AWS side of a trust relationship between an AWS Managed Microsoft AD directory and an external domain. You can create either a forest trust or an external trust.

    Args:
        directory_id(str): The Directory ID of the AWS Managed Microsoft AD directory for which to establish the trust relationship.
        remote_domain_name(str): The Fully Qualified Domain Name (FQDN) of the external domain for which to create the trust relationship.
        trust_password(str): The trust password. The must be the same password that was used when creating the trust relationship on the external domain.
        trust_direction(str): The direction of the trust relationship.
        trust_type(str, optional): The trust relationship type. Forest is the default. Defaults to None.
        conditional_forwarder_ip_addrs(List, optional): The IP addresses of the remote DNS server associated with RemoteDomainName. Defaults to None.
        selective_auth(str, optional): Optional parameter to enable selective authentication for the trust. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.trust.create(
                ctx,
                directory_id=value,
                remote_domain_name=value,
                trust_password=value,
                trust_direction=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.trust.create directory_id=value, remote_domain_name=value, trust_password=value, trust_direction=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="create_trust",
        op_kwargs={
            "DirectoryId": directory_id,
            "RemoteDomainName": remote_domain_name,
            "TrustPassword": trust_password,
            "TrustDirection": trust_direction,
            "TrustType": trust_type,
            "ConditionalForwarderIpAddrs": conditional_forwarder_ip_addrs,
            "SelectiveAuth": selective_auth,
        },
    )


async def delete(
    hub, ctx, trust_id: str, delete_associated_conditional_forwarder: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing trust relationship between your AWS Managed Microsoft AD directory and an external domain.

    Args:
        trust_id(str): The Trust ID of the trust relationship to be deleted.
        delete_associated_conditional_forwarder(bool, optional): Delete a conditional forwarder as part of a DeleteTrustRequest. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.trust.delete(ctx, trust_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.trust.delete trust_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="delete_trust",
        op_kwargs={
            "TrustId": trust_id,
            "DeleteAssociatedConditionalForwarder": delete_associated_conditional_forwarder,
        },
    )


async def describe_all(
    hub,
    ctx,
    directory_id: str = None,
    trust_ids: List = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Obtains information about the trust relationships for this account. If no input parameters are provided, such as DirectoryId or TrustIds, this request describes all the trust relationships belonging to the account.

    Args:
        directory_id(str, optional): The Directory ID of the AWS directory that is a part of the requested trust relationship. Defaults to None.
        trust_ids(List, optional): A list of identifiers of the trust relationships for which to obtain the information. If this member is null, all trust relationships that belong to the current account are returned. An empty list results in an InvalidParameterException being thrown. Defaults to None.
        next_token(str, optional): The DescribeTrustsResult.NextToken value from a previous call to DescribeTrusts. Pass null if this is the first call. Defaults to None.
        limit(int, optional): The maximum number of objects to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.trust.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.trust.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="describe_trusts",
        op_kwargs={
            "DirectoryId": directory_id,
            "TrustIds": trust_ids,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def update(hub, ctx, trust_id: str, selective_auth: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the trust that has been set up between your AWS Managed Microsoft AD directory and an on-premises Active Directory.

    Args:
        trust_id(str): Identifier of the trust relationship.
        selective_auth(str, optional): Updates selective authentication for the trust. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.trust.update(ctx, trust_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.trust.update trust_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="update_trust",
        op_kwargs={"TrustId": trust_id, "SelectiveAuth": selective_auth},
    )


async def verify(hub, ctx, trust_id: str) -> Dict:
    r"""
    **Autogenerated function**

    AWS Directory Service for Microsoft Active Directory allows you to configure and verify trust relationships. This action verifies a trust relationship between your AWS Managed Microsoft AD directory and an external domain.

    Args:
        trust_id(str): The unique Trust ID of the trust relationship to verify.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.trust.verify(ctx, trust_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.trust.verify trust_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="verify_trust",
        op_kwargs={"TrustId": trust_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    aws_account_id: str,
    theme_id: str,
    alias_name: str,
    theme_version_number: int,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a theme alias for a theme.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the theme for the new theme alias.
        theme_id(str): An ID for the theme alias.
        alias_name(str): The name that you want to give to the theme alias that you are creating. The alias name can't begin with a $. Alias names that start with $ are reserved by Amazon QuickSight. .
        theme_version_number(int): The version number of the theme.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.theme.alias.create(
                ctx,
                aws_account_id=value,
                theme_id=value,
                alias_name=value,
                theme_version_number=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.theme.alias.create aws_account_id=value, theme_id=value, alias_name=value, theme_version_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_theme_alias",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "ThemeId": theme_id,
            "AliasName": alias_name,
            "ThemeVersionNumber": theme_version_number,
        },
    )


async def delete(hub, ctx, aws_account_id: str, theme_id: str, alias_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the version of the theme that the specified theme alias points to. If you provide a specific alias, you delete the version of the theme that the alias points to.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the theme alias to delete.
        theme_id(str): The ID for the theme that the specified alias is for.
        alias_name(str): The unique name for the theme alias to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.theme.alias.delete(
                ctx, aws_account_id=value, theme_id=value, alias_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.theme.alias.delete aws_account_id=value, theme_id=value, alias_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_theme_alias",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "ThemeId": theme_id,
            "AliasName": alias_name,
        },
    )


async def describe(
    hub, ctx, aws_account_id: str, theme_id: str, alias_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the alias for a theme.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the theme alias that you're describing.
        theme_id(str): The ID for the theme.
        alias_name(str): The name of the theme alias that you want to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.theme.alias.describe(
                ctx, aws_account_id=value, theme_id=value, alias_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.theme.alias.describe aws_account_id=value, theme_id=value, alias_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_theme_alias",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "ThemeId": theme_id,
            "AliasName": alias_name,
        },
    )


async def update(
    hub,
    ctx,
    aws_account_id: str,
    theme_id: str,
    alias_name: str,
    theme_version_number: int,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an alias of a theme.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the theme alias that you're updating.
        theme_id(str): The ID for the theme.
        alias_name(str): The name of the theme alias that you want to update.
        theme_version_number(int): The version number of the theme that the alias should reference.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.theme.alias.update(
                ctx,
                aws_account_id=value,
                theme_id=value,
                alias_name=value,
                theme_version_number=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.theme.alias.update aws_account_id=value, theme_id=value, alias_name=value, theme_version_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_theme_alias",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "ThemeId": theme_id,
            "AliasName": alias_name,
            "ThemeVersionNumber": theme_version_number,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, instance_id: str, quick_connect_id: str, quick_connect_config: Dict
) -> None:
    r"""
    **Autogenerated function**

    Updates the configuration settings for the specified quick connect.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        quick_connect_id(str): The identifier for the quick connect.
        quick_connect_config(Dict): Information about the configuration settings for the quick connect.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.quick_connect.config.update(
                ctx, instance_id=value, quick_connect_id=value, quick_connect_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.quick_connect.config.update instance_id=value, quick_connect_id=value, quick_connect_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="update_quick_connect_config",
        op_kwargs={
            "InstanceId": instance_id,
            "QuickConnectId": quick_connect_id,
            "QuickConnectConfig": quick_connect_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    authentication_type: str,
    log_config: Dict = None,
    user_pool_config: Dict = None,
    open_id_connect_config: Dict = None,
    tags: Dict = None,
    additional_authentication_providers: List = None,
    xray_enabled: bool = None,
    lambda_authorizer_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a GraphqlApi object.

    Args:
        name(str): A user-supplied name for the GraphqlApi.
        log_config(Dict, optional): The Amazon CloudWatch Logs configuration. Defaults to None.
        authentication_type(str): The authentication type: API key, Identity and Access Management, OIDC, or Amazon Cognito user pools.
        user_pool_config(Dict, optional): The Amazon Cognito user pool configuration. Defaults to None.
        open_id_connect_config(Dict, optional): The OpenID Connect configuration. Defaults to None.
        tags(Dict, optional): A TagMap object. Defaults to None.
        additional_authentication_providers(List, optional): A list of additional authentication providers for the GraphqlApi API. Defaults to None.
        xray_enabled(bool, optional): A flag indicating whether to enable X-Ray tracing for the GraphqlApi. Defaults to None.
        lambda_authorizer_config(Dict, optional): Configuration for AWS Lambda function authorization. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.graphql_api.create(
                ctx, name=value, authentication_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.graphql_api.create name=value, authentication_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="create_graphql_api",
        op_kwargs={
            "name": name,
            "logConfig": log_config,
            "authenticationType": authentication_type,
            "userPoolConfig": user_pool_config,
            "openIDConnectConfig": open_id_connect_config,
            "tags": tags,
            "additionalAuthenticationProviders": additional_authentication_providers,
            "xrayEnabled": xray_enabled,
            "lambdaAuthorizerConfig": lambda_authorizer_config,
        },
    )


async def delete(hub, ctx, api_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a GraphqlApi object.

    Args:
        api_id(str): The API ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.graphql_api.delete(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.graphql_api.delete api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="delete_graphql_api",
        op_kwargs={"apiId": api_id},
    )


async def get(hub, ctx, api_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a GraphqlApi object.

    Args:
        api_id(str): The API ID for the GraphQL API.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.graphql_api.get(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.graphql_api.get api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="get_graphql_api",
        op_kwargs={"apiId": api_id},
    )


async def update(
    hub,
    ctx,
    api_id: str,
    name: str,
    log_config: Dict = None,
    authentication_type: str = None,
    user_pool_config: Dict = None,
    open_id_connect_config: Dict = None,
    additional_authentication_providers: List = None,
    xray_enabled: bool = None,
    lambda_authorizer_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a GraphqlApi object.

    Args:
        api_id(str): The API ID.
        name(str): The new name for the GraphqlApi object.
        log_config(Dict, optional): The Amazon CloudWatch Logs configuration for the GraphqlApi object. Defaults to None.
        authentication_type(str, optional): The new authentication type for the GraphqlApi object. Defaults to None.
        user_pool_config(Dict, optional): The new Amazon Cognito user pool configuration for the GraphqlApi object. Defaults to None.
        open_id_connect_config(Dict, optional): The OpenID Connect configuration for the GraphqlApi object. Defaults to None.
        additional_authentication_providers(List, optional): A list of additional authentication providers for the GraphqlApi API. Defaults to None.
        xray_enabled(bool, optional): A flag indicating whether to enable X-Ray tracing for the GraphqlApi. Defaults to None.
        lambda_authorizer_config(Dict, optional): Configuration for AWS Lambda function authorization. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.graphql_api.update(ctx, api_id=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.graphql_api.update api_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="update_graphql_api",
        op_kwargs={
            "apiId": api_id,
            "name": name,
            "logConfig": log_config,
            "authenticationType": authentication_type,
            "userPoolConfig": user_pool_config,
            "openIDConnectConfig": open_id_connect_config,
            "additionalAuthenticationProviders": additional_authentication_providers,
            "xrayEnabled": xray_enabled,
            "lambdaAuthorizerConfig": lambda_authorizer_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, suite_definition_id: str, suite_run_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a report download link for a successful Device Advisor qualifying test suite run.

    Args:
        suite_definition_id(str): Suite definition Id of the test suite.
        suite_run_id(str): Suite run Id of the test suite run.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotdeviceadvisor.suite.run.report.get(
                ctx, suite_definition_id=value, suite_run_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotdeviceadvisor.suite.run.report.get suite_definition_id=value, suite_run_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotdeviceadvisor",
        operation="get_suite_run_report",
        op_kwargs={
            "suiteDefinitionId": suite_definition_id,
            "suiteRunId": suite_run_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"set_": "set"}


async def set_(
    hub,
    ctx,
    instance_ids: List,
    auto_scaling_group_name: str,
    protected_from_scale_in: bool,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the instance protection settings of the specified instances. This operation cannot be called on instances in a warm pool. For more information about preventing instances that are part of an Auto Scaling group from terminating on scale in, see Instance scale-in protection in the Amazon EC2 Auto Scaling User Guide. If you exceed your maximum limit of instance IDs, which is 50 per Auto Scaling group, the call fails.

    Args:
        instance_ids(List): One or more instance IDs. You can specify up to 50 instances.
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        protected_from_scale_in(bool): Indicates whether the instance is protected from termination by Amazon EC2 Auto Scaling when scaling in.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.instance.protection.set(
                ctx,
                instance_ids=value,
                auto_scaling_group_name=value,
                protected_from_scale_in=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.instance.protection.set instance_ids=value, auto_scaling_group_name=value, protected_from_scale_in=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="set_instance_protection",
        op_kwargs={
            "InstanceIds": instance_ids,
            "AutoScalingGroupName": auto_scaling_group_name,
            "ProtectedFromScaleIn": protected_from_scale_in,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "apps_list"


async def delete(hub, ctx, list_id: str) -> None:
    r"""
    **Autogenerated function**

    Permanently deletes an Firewall Manager applications list.

    Args:
        list_id(str): The ID of the applications list that you want to delete. You can retrieve this ID from PutAppsList, ListAppsLists, and GetAppsList.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.apps_list_.delete(ctx, list_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.apps_list.delete list_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="delete_apps_list",
        op_kwargs={"ListId": list_id},
    )


async def get(hub, ctx, list_id: str, default_list: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified Firewall Manager applications list.

    Args:
        list_id(str): The ID of the Firewall Manager applications list that you want the details for.
        default_list(bool, optional): Specifies whether the list to retrieve is a default list owned by Firewall Manager. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.apps_list_.get(ctx, list_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.apps_list.get list_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="get_apps_list",
        op_kwargs={"ListId": list_id, "DefaultList": default_list},
    )


async def list_all(
    hub, ctx, max_results: int, default_lists: bool = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of AppsListDataSummary objects.

    Args:
        default_lists(bool, optional): Specifies whether the lists to retrieve are default lists owned by Firewall Manager. Defaults to None.
        next_token(str, optional): If you specify a value for MaxResults in your list request, and you have more objects than the maximum, Firewall Manager returns this token in the response. For all but the first request, you provide the token returned by the prior request in the request parameters, to retrieve the next batch of objects. Defaults to None.
        max_results(int): The maximum number of objects that you want Firewall Manager to return for this request. If more objects are available, in the response, Firewall Manager provides a NextToken value that you can use in a subsequent call to get the next batch of objects. If you don't specify this, Firewall Manager returns all available objects.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.apps_list_.list_all(ctx, max_results=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.apps_list.list_all max_results=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="list_apps_lists",
        op_kwargs={
            "DefaultLists": default_lists,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def put(hub, ctx, apps_list: Dict, tag_list: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Firewall Manager applications list.

    Args:
        apps_list(Dict): The details of the Firewall Manager applications list to be created.
        tag_list(List, optional): The tags associated with the resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.apps_list_.put(ctx, apps_list=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.apps_list.put apps_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="put_apps_list",
        op_kwargs={"AppsList": apps_list, "TagList": tag_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def abort(
    hub, ctx, environment_id: str = None, environment_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Cancels in-progress environment configuration update or application version deployment.

    Args:
        environment_id(str, optional): This specifies the ID of the environment with the in-progress update that you want to cancel. Defaults to None.
        environment_name(str, optional): This specifies the name of the environment with the in-progress update that you want to cancel. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.update.abort(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.update.abort
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="abort_environment_update",
        op_kwargs={
            "EnvironmentId": environment_id,
            "EnvironmentName": environment_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Associates tags with the specified Amazon Web Services resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to "customer" and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource. You can tag the Amazon Web Services resources that you manage through WAF: web ACLs, rule groups, IP sets, and regex pattern sets. You can't manage or view tags through the WAF console.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.
        tags(List): An array of key:value pairs to associate with the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.resource.init.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.resource.init.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates tags from an Amazon Web Services resource. Tags are key:value pairs that you can associate with Amazon Web Services resources. For example, the tag key might be "customer" and the tag value might be "companyA." You can specify one or more tags to add to each container. You can add up to 50 tags to each Amazon Web Services resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.
        tag_keys(List): An array of keys identifying the tags to disassociate from the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.resource.init.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.resource.init.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, load_balancer_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the attributes for the specified load balancer.

    Args:
        load_balancer_name(str): The name of the load balancer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.attribute.describe_all(
                ctx, load_balancer_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.attribute.describe_all load_balancer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="describe_load_balancer_attributes",
        op_kwargs={"LoadBalancerName": load_balancer_name},
    )


async def modify(
    hub, ctx, load_balancer_name: str, load_balancer_attributes: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the attributes of the specified load balancer. You can modify the load balancer attributes, such as AccessLogs, ConnectionDraining, and CrossZoneLoadBalancing by either enabling or disabling them. Or, you can modify the load balancer attribute ConnectionSettings by specifying an idle connection timeout value for your load balancer. For more information, see the following in the Classic Load Balancers Guide:    Cross-Zone Load Balancing     Connection Draining     Access Logs     Idle Connection Timeout

    Args:
        load_balancer_name(str): The name of the load balancer.
        load_balancer_attributes(Dict): The attributes for the load balancer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.attribute.modify(
                ctx, load_balancer_name=value, load_balancer_attributes=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.attribute.modify load_balancer_name=value, load_balancer_attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="modify_load_balancer_attributes",
        op_kwargs={
            "LoadBalancerName": load_balancer_name,
            "LoadBalancerAttributes": load_balancer_attributes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def synthesize(
    hub,
    ctx,
    output_format: str,
    text: str,
    voice_id: str,
    engine: str = None,
    language_code: str = None,
    lexicon_names: List = None,
    sample_rate: str = None,
    speech_mark_types: List = None,
    text_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Synthesizes UTF-8 input, plain text or SSML, to a stream of bytes. SSML input must be valid, well-formed SSML. Some alphabets might not be available with all the voices (for example, Cyrillic might not be read at all by English voices) unless phoneme mapping is used. For more information, see How it Works.

    Args:
        engine(str, optional): Specifies the engine (standard or neural) for Amazon Polly to use when processing input text for speech synthesis. For information on Amazon Polly voices and which voices are available in standard-only, NTTS-only, and both standard and NTTS formats, see Available Voices.  NTTS-only voices  When using NTTS-only voices such as Kevin (en-US), this parameter is required and must be set to neural. If the engine is not specified, or is set to standard, this will result in an error.  Type: String Valid Values: standard | neural  Required: Yes  Standard voices  For standard voices, this is not required; the engine parameter defaults to standard. If the engine is not specified, or is set to standard and an NTTS-only voice is selected, this will result in an error. . Defaults to None.
        language_code(str, optional): Optional language code for the Synthesize Speech request. This is only necessary if using a bilingual voice, such as Aditi, which can be used for either Indian English (en-IN) or Hindi (hi-IN).  If a bilingual voice is used and no language code is specified, Amazon Polly will use the default language of the bilingual voice. The default language for any voice is the one returned by the DescribeVoices operation for the LanguageCode parameter. For example, if no language code is specified, Aditi will use Indian English rather than Hindi. Defaults to None.
        lexicon_names(List, optional): List of one or more pronunciation lexicon names you want the service to apply during synthesis. Lexicons are applied only if the language of the lexicon is the same as the language of the voice. For information about storing lexicons, see PutLexicon. Defaults to None.
        output_format(str):  The format in which the returned output will be encoded. For audio stream, this will be mp3, ogg_vorbis, or pcm. For speech marks, this will be json.  When pcm is used, the content returned is audio/pcm in a signed 16-bit, 1 channel (mono), little-endian format. .
        sample_rate(str, optional): The audio frequency specified in Hz. The valid values for mp3 and ogg_vorbis are "8000", "16000", "22050", and "24000". The default value for standard voices is "22050". The default value for neural voices is "24000". Valid values for pcm are "8000" and "16000" The default value is "16000". . Defaults to None.
        speech_mark_types(List, optional): The type of speech marks returned for the input text. Defaults to None.
        text(str):  Input text to synthesize. If you specify ssml as the TextType, follow the SSML format for the input text. .
        text_type(str, optional):  Specifies whether the input text is plain text or SSML. The default value is plain text. For more information, see Using SSML. Defaults to None.
        voice_id(str):  Voice ID to use for the synthesis. You can get a list of available voice IDs by calling the DescribeVoices operation. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.polly.speech.init.synthesize(
                ctx, output_format=value, text=value, voice_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.polly.speech.init.synthesize output_format=value, text=value, voice_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="polly",
        operation="synthesize_speech",
        op_kwargs={
            "Engine": engine,
            "LanguageCode": language_code,
            "LexiconNames": lexicon_names,
            "OutputFormat": output_format,
            "SampleRate": sample_rate,
            "SpeechMarkTypes": speech_mark_types,
            "Text": text,
            "TextType": text_type,
            "VoiceId": voice_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(
    hub, ctx, client_token: str, job_id: str, organization_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a mailbox export job.  If the mailbox export job is near completion, it might not be possible to cancel it.

    Args:
        client_token(str): The idempotency token for the client request.
        job_id(str): The job ID.
        organization_id(str): The organization ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mailbox.export_job.cancel(
                ctx, client_token=value, job_id=value, organization_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mailbox.export_job.cancel client_token=value, job_id=value, organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="cancel_mailbox_export_job",
        op_kwargs={
            "ClientToken": client_token,
            "JobId": job_id,
            "OrganizationId": organization_id,
        },
    )


async def describe(hub, ctx, job_id: str, organization_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the current status of a mailbox export job.

    Args:
        job_id(str): The mailbox export job ID.
        organization_id(str): The organization ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mailbox.export_job.describe(
                ctx, job_id=value, organization_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mailbox.export_job.describe job_id=value, organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="describe_mailbox_export_job",
        op_kwargs={"JobId": job_id, "OrganizationId": organization_id},
    )


async def list_all(
    hub, ctx, organization_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the mailbox export jobs started for the specified organization within the last seven days.

    Args:
        organization_id(str): The organization ID.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mailbox.export_job.list_all(ctx, organization_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mailbox.export_job.list_all organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="list_mailbox_export_jobs",
        op_kwargs={
            "OrganizationId": organization_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    client_token: str,
    organization_id: str,
    entity_id: str,
    role_arn: str,
    kms_key_arn: str,
    s3_bucket_name: str,
    s3_prefix: str,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a mailbox export job to export MIME-format email messages and calendar items from the specified mailbox to the specified Amazon Simple Storage Service (Amazon S3) bucket. For more information, see Exporting mailbox content in the Amazon WorkMail Administrator Guide.

    Args:
        client_token(str): The idempotency token for the client request.
        organization_id(str): The identifier associated with the organization.
        entity_id(str): The identifier of the user or resource associated with the mailbox.
        description(str, optional): The mailbox export job description. Defaults to None.
        role_arn(str): The ARN of the AWS Identity and Access Management (IAM) role that grants write permission to the S3 bucket.
        kms_key_arn(str): The Amazon Resource Name (ARN) of the symmetric AWS Key Management Service (AWS KMS) key that encrypts the exported mailbox content.
        s3_bucket_name(str): The name of the S3 bucket.
        s3_prefix(str): The S3 bucket prefix.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mailbox.export_job.start(
                ctx,
                client_token=value,
                organization_id=value,
                entity_id=value,
                role_arn=value,
                kms_key_arn=value,
                s3_bucket_name=value,
                s3_prefix=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mailbox.export_job.start client_token=value, organization_id=value, entity_id=value, role_arn=value, kms_key_arn=value, s3_bucket_name=value, s3_prefix=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="start_mailbox_export_job",
        op_kwargs={
            "ClientToken": client_token,
            "OrganizationId": organization_id,
            "EntityId": entity_id,
            "Description": description,
            "RoleArn": role_arn,
            "KmsKeyArn": kms_key_arn,
            "S3BucketName": s3_bucket_name,
            "S3Prefix": s3_prefix,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete_multiple(hub, ctx, app_instance_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the streaming configurations of an AppInstance.

    Args:
        app_instance_arn(str): The ARN of the streaming configurations being deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.streaming_configuration.delete_multiple(
                ctx, app_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.streaming_configuration.delete_multiple app_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_app_instance_streaming_configurations",
        op_kwargs={"AppInstanceArn": app_instance_arn},
    )


async def get_all(hub, ctx, app_instance_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the streaming settings for an AppInstance.

    Args:
        app_instance_arn(str): The ARN of the AppInstance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.streaming_configuration.get_all(
                ctx, app_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.streaming_configuration.get_all app_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_app_instance_streaming_configurations",
        op_kwargs={"AppInstanceArn": app_instance_arn},
    )


async def put_multiple(
    hub, ctx, app_instance_arn: str, app_instance_streaming_configurations: List
) -> Dict:
    r"""
    **Autogenerated function**

    The data streaming configurations of an AppInstance.

    Args:
        app_instance_arn(str): The ARN of the AppInstance.
        app_instance_streaming_configurations(List): The streaming configurations set for an AppInstance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.streaming_configuration.put_multiple(
                ctx, app_instance_arn=value, app_instance_streaming_configurations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.streaming_configuration.put_multiple app_instance_arn=value, app_instance_streaming_configurations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="put_app_instance_streaming_configurations",
        op_kwargs={
            "AppInstanceArn": app_instance_arn,
            "AppInstanceStreamingConfigurations": app_instance_streaming_configurations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a version of an Lambda layer, with a link to download the layer archive that's valid for 10 minutes.

    Args:
        arn(str): The ARN of the layer version.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.layer.version.by_arn.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.layer.version.by_arn.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="get_layer_version_by_arn",
        op_kwargs={"Arn": arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, id_: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the tags for a project.

    Args:
        id_(str): The ID of the project to get tags for.
        next_token(str, optional): Reserved for future use. Defaults to None.
        max_results(int, optional): Reserved for future use. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.tags_for_project.list(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.tags_for_project.list id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="list_tags_for_project",
        op_kwargs={"id": id_, "nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, name: str, schema_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Directory by copying the published schema into the directory. A directory cannot be created without a schema. You can also quickly create a directory using a managed schema, called the QuickStartSchema. For more information, see Managed Schema in the Amazon Cloud Directory Developer Guide.

    Args:
        name(str): The name of the Directory. Should be unique per account, per region.
        schema_arn(str): The Amazon Resource Name (ARN) of the published schema that will be copied into the data Directory. For more information, see arns.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.directory.create(
                ctx, name=value, schema_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.directory.create name=value, schema_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="create_directory",
        op_kwargs={"Name": name, "SchemaArn": schema_arn},
    )


async def delete(hub, ctx, directory_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a directory. Only disabled directories can be deleted. A deleted directory cannot be undone. Exercise extreme caution when deleting directories.

    Args:
        directory_arn(str): The ARN of the directory to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.directory.delete(ctx, directory_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.directory.delete directory_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="delete_directory",
        op_kwargs={"DirectoryArn": directory_arn},
    )


async def disable(hub, ctx, directory_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables the specified directory. Disabled directories cannot be read or written to. Only enabled directories can be disabled. Disabled directories may be reenabled.

    Args:
        directory_arn(str): The ARN of the directory to disable.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.directory.disable(ctx, directory_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.directory.disable directory_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="disable_directory",
        op_kwargs={"DirectoryArn": directory_arn},
    )


async def enable(hub, ctx, directory_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Enables the specified directory. Only disabled directories can be enabled. Once enabled, the directory can then be read and written to.

    Args:
        directory_arn(str): The ARN of the directory to enable.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.directory.enable(ctx, directory_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.directory.enable directory_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="enable_directory",
        op_kwargs={"DirectoryArn": directory_arn},
    )


async def get(hub, ctx, directory_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves metadata about a directory.

    Args:
        directory_arn(str): The ARN of the directory.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.directory.get(ctx, directory_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.directory.get directory_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="get_directory",
        op_kwargs={"DirectoryArn": directory_arn},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, state: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists directories created within an account.

    Args:
        next_token(str, optional): The pagination token. Defaults to None.
        max_results(int, optional): The maximum number of results to retrieve. Defaults to None.
        state(str, optional): The state of the directories in the list. Can be either Enabled, Disabled, or Deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.directory.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.directory.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="list_directories",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results, "state": state},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, account: Dict, tags: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Associates an account with an Amazon Macie administrator account.

    Args:
        account(Dict): The details of the account to associate with the administrator account.
        tags(Dict, optional): A map of key-value pairs that specifies the tags to associate with the account in Amazon Macie. An account can have a maximum of 50 tags. Each tag consists of a tag key and an associated tag value. The maximum length of a tag key is 128 characters. The maximum length of a tag value is 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.member.init.create(ctx, account=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.member.init.create account=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="create_member",
        op_kwargs={"account": account, "tags": tags},
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the association between an Amazon Macie administrator account and an account.

    Args:
        id_(str): The unique identifier for the Amazon Macie resource or account that the request applies to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.member.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.member.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="macie2", operation="delete_member", op_kwargs={"id": id_}
    )


async def disassociate(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates an Amazon Macie administrator account from a member account.

    Args:
        id_(str): The unique identifier for the Amazon Macie resource or account that the request applies to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.member.init.disassociate(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.member.init.disassociate id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="disassociate_member",
        op_kwargs={"id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about an account that's associated with an Amazon Macie administrator account.

    Args:
        id_(str): The unique identifier for the Amazon Macie resource or account that the request applies to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.member.init.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.member.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="macie2", operation="get_member", op_kwargs={"id": id_}
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    only_associated: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the accounts that are associated with an Amazon Macie administrator account.

    Args:
        max_results(int, optional): The maximum number of items to include in each page of a paginated response. Defaults to None.
        next_token(str, optional): The nextToken string that specifies which page of results to return in a paginated response. Defaults to None.
        only_associated(str, optional): Specifies which accounts to include in the response, based on the status of an account's relationship with the administrator account. By default, the response includes only current member accounts. To include all accounts, set this value to false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.member.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.member.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="list_members",
        op_kwargs={
            "maxResults": max_results,
            "nextToken": next_token,
            "onlyAssociated": only_associated,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    stack_name: str,
    fleet_name: str,
    user_id: str = None,
    next_token: str = None,
    limit: int = None,
    authentication_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes the streaming sessions for a specified stack and fleet. If a UserId is provided for the stack and fleet, only streaming sessions for that user are described. If an authentication type is not provided, the default is to authenticate users using a streaming URL.

    Args:
        stack_name(str): The name of the stack. This value is case-sensitive.
        fleet_name(str): The name of the fleet. This value is case-sensitive.
        user_id(str, optional): The user identifier (ID). If you specify a user ID, you must also specify the authentication type. Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.
        limit(int, optional): The size of each page of results. The default value is 20 and the maximum value is 50. Defaults to None.
        authentication_type(str, optional): The authentication method. Specify API for a user authenticated using a streaming URL or SAML for a SAML federated user. The default is to authenticate users using a streaming URL. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.session.describe_all(
                ctx, stack_name=value, fleet_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.session.describe_all stack_name=value, fleet_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="describe_sessions",
        op_kwargs={
            "StackName": stack_name,
            "FleetName": fleet_name,
            "UserId": user_id,
            "NextToken": next_token,
            "Limit": limit,
            "AuthenticationType": authentication_type,
        },
    )


async def expire(hub, ctx, session_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Immediately stops the specified streaming session.

    Args:
        session_id(str): The identifier of the streaming session.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.session.expire(ctx, session_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.session.expire session_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="expire_session",
        op_kwargs={"SessionId": session_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete an incident record from Incident Manager.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the incident record you are deleting.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.incident.record.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.incident.record.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="delete_incident_record",
        op_kwargs={"arn": arn},
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the details of the specified incident record.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the incident record.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.incident.record.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.incident.record.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="get_incident_record",
        op_kwargs={"arn": arn},
    )


async def list_all(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all incident records in your account. Use this command to retrieve the Amazon Resource Name (ARN) of the incident record you want to update.

    Args:
        filters(List, optional): Filter the list of incident records you are searching through. You can filter on the following keys:    creationTime     impact     status     createdBy   . Defaults to None.
        max_results(int, optional): The maximum number of results per page. Defaults to None.
        next_token(str, optional): The pagination token to continue to the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.incident.record.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.incident.record.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="list_incident_records",
        op_kwargs={
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    arn: str,
    chat_channel: Dict = None,
    client_token: str = None,
    impact: int = None,
    notification_targets: List = None,
    status: str = None,
    summary: str = None,
    title: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update the details of an incident record. You can use this action to update an incident record from the defined chat channel. For more information about using actions in chat channels, see Interacting through chat.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the incident record you are updating.
        chat_channel(Dict, optional): The AWS Chatbot chat channel for responders to collaborate in. Defaults to None.
        client_token(str, optional): A token ensuring that the action is called only once with the specified details. Defaults to None.
        impact(int, optional): Defines the impact to customers and applications. Providing an impact overwrites the impact provided by the response plan.  Possible impacts:     1 - Critical impact, this typically relates to full application failure that impacts many to all customers.     2 - High impact, partial application failure with impact to many customers.    3 - Medium impact, the application is providing reduced service to customers.    4 - Low impact, customer might aren't impacted by the problem yet.    5 - No impact, customers aren't currently impacted but urgent action is needed to avoid impact.  . Defaults to None.
        notification_targets(List, optional): The SNS targets that AWS Chatbot uses to notify the chat channel of updates to an incident. You can also make updates to the incident through the chat channel using the SNS topics.  Using multiple SNS topics creates redundancy in the case that a Region is down during the incident. Defaults to None.
        status(str, optional): The status of the incident. An incident can be Open or Resolved. Defaults to None.
        summary(str, optional): The summary describes what has happened during the incident. Defaults to None.
        title(str, optional): The title of the incident is a brief and easily recognizable. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.incident.record.update(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.incident.record.update arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="update_incident_record",
        op_kwargs={
            "arn": arn,
            "chatChannel": chat_channel,
            "clientToken": client_token,
            "impact": impact,
            "notificationTargets": notification_targets,
            "status": status,
            "summary": summary,
            "title": title,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def update(hub, ctx, repository_name: str, default_branch_name: str) -> None:
    r"""
    **Autogenerated function**

    Sets or changes the default branch name for the specified repository.  If you use this operation to change the default branch name to the current default branch name, a success message is returned even though the default branch did not change.

    Args:
        repository_name(str): The name of the repository to set or change the default branch for.
        default_branch_name(str): The name of the branch to set as the default.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.default_branch.update(
                ctx, repository_name=value, default_branch_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.default_branch.update repository_name=value, default_branch_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="update_default_branch",
        op_kwargs={
            "repositoryName": repository_name,
            "defaultBranchName": default_branch_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def start(hub, ctx, source_server_i_ds: List, tags: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Lauches a Test Instance for specific Source Servers. This command starts a LAUNCH job whose initiatedBy property is StartTest and changes the SourceServer.lifeCycle.state property to TESTING.

    Args:
        source_server_i_ds(List): Start Test for Source Server IDs.
        tags(Dict, optional): Start Test by Tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.test.start(ctx, source_server_i_ds=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.test.start source_server_i_ds=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="start_test",
        op_kwargs={"sourceServerIDs": source_server_i_ds, "tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, auto_enable_controls: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates configuration options for Security Hub.

    Args:
        auto_enable_controls(bool, optional): Whether to automatically enable new controls when they are added to standards that are enabled. By default, this is set to true, and new controls are enabled automatically. To not automatically enable new controls, set this to false. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.security_hub.configuration.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.security_hub.configuration.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="update_security_hub_configuration",
        op_kwargs={"AutoEnableControls": auto_enable_controls},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(hub, ctx, job_id: str, client_token: str, failure_details: Dict) -> None:
    r"""
    **Autogenerated function**

    Represents the failure of a third party job as returned to the pipeline by a job worker. Used for partner actions only.

    Args:
        job_id(str): The ID of the job that failed. This is the same ID returned from PollForThirdPartyJobs.
        client_token(str): The clientToken portion of the clientId and clientToken pair used to verify that the calling entity is allowed access to the job and its details.
        failure_details(Dict): Represents information about failure details.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.third_party_job.failure_result.put(
                ctx, job_id=value, client_token=value, failure_details=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.third_party_job.failure_result.put job_id=value, client_token=value, failure_details=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="put_third_party_job_failure_result",
        op_kwargs={
            "jobId": job_id,
            "clientToken": client_token,
            "failureDetails": failure_details,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, next_token: str = None, stream_arn: str = None, stream_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of tags associated with the specified stream. In the request, you must specify either the StreamName or the StreamARN.

    Args:
        next_token(str, optional): If you specify this parameter and the result of a ListTagsForStream call is truncated, the response includes a token that you can use in the next request to fetch the next batch of tags. Defaults to None.
        stream_arn(str, optional): The Amazon Resource Name (ARN) of the stream that you want to list tags for. Defaults to None.
        stream_name(str, optional): The name of the stream that you want to list tags for. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.tags_for_.stream.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.tags_for_.stream.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="list_tags_for_stream",
        op_kwargs={
            "NextToken": next_token,
            "StreamARN": stream_arn,
            "StreamName": stream_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "class"


async def update(
    hub, ctx, channel_class: str, channel_id: str, destinations: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the class of the channel.

    Args:
        channel_class(str): The channel class that you wish to update this channel to use.
        channel_id(str): Channel Id of the channel whose class should be updated.
        destinations(List, optional): A list of output destinations for this channel. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.channel.class_.update(
                ctx, channel_class=value, channel_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.channel.class.update channel_class=value, channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="update_channel_class",
        op_kwargs={
            "ChannelClass": channel_class,
            "ChannelId": channel_id,
            "Destinations": destinations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, copy_job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata associated with creating a copy of a resource.

    Args:
        copy_job_id(str): Uniquely identifies a copy job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.copy_job.describe(ctx, copy_job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.copy_job.describe copy_job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="describe_copy_job",
        op_kwargs={"CopyJobId": copy_job_id},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    by_resource_arn: str = None,
    by_state: str = None,
    by_created_before: str = None,
    by_created_after: str = None,
    by_resource_type: str = None,
    by_destination_vault_arn: str = None,
    by_account_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata about your copy jobs.

    Args:
        next_token(str, optional): The next item following a partial list of returned items. For example, if a request is made to return maxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token. . Defaults to None.
        max_results(int, optional): The maximum number of items to be returned. Defaults to None.
        by_resource_arn(str, optional): Returns only copy jobs that match the specified resource Amazon Resource Name (ARN). . Defaults to None.
        by_state(str, optional): Returns only copy jobs that are in the specified state. Defaults to None.
        by_created_before(str, optional): Returns only copy jobs that were created before the specified date. Defaults to None.
        by_created_after(str, optional): Returns only copy jobs that were created after the specified date. Defaults to None.
        by_resource_type(str, optional): Returns only backup jobs for the specified resources:    DynamoDB for Amazon DynamoDB    EBS for Amazon Elastic Block Store    EC2 for Amazon Elastic Compute Cloud    EFS for Amazon Elastic File System    RDS for Amazon Relational Database Service    Aurora for Amazon Aurora    Storage Gateway for AWS Storage Gateway  . Defaults to None.
        by_destination_vault_arn(str, optional): An Amazon Resource Name (ARN) that uniquely identifies a source backup vault to copy from; for example, arn:aws:backup:us-east-1:123456789012:vault:aBackupVault. . Defaults to None.
        by_account_id(str, optional): The account ID to list the jobs from. Returns only copy jobs associated with the specified account ID. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.copy_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.copy_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="list_copy_jobs",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "ByResourceArn": by_resource_arn,
            "ByState": by_state,
            "ByCreatedBefore": by_created_before,
            "ByCreatedAfter": by_created_after,
            "ByResourceType": by_resource_type,
            "ByDestinationVaultArn": by_destination_vault_arn,
            "ByAccountId": by_account_id,
        },
    )


async def start(
    hub,
    ctx,
    recovery_point_arn: str,
    source_backup_vault_name: str,
    destination_backup_vault_arn: str,
    iam_role_arn: str,
    idempotency_token: str = None,
    lifecycle: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a job to create a one-time copy of the specified resource. Does not support continuous backups.

    Args:
        recovery_point_arn(str): An ARN that uniquely identifies a recovery point to use for the copy job; for example, arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45. .
        source_backup_vault_name(str): The name of a logical source container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of lowercase letters, numbers, and hyphens.
        destination_backup_vault_arn(str): An Amazon Resource Name (ARN) that uniquely identifies a destination backup vault to copy to; for example, arn:aws:backup:us-east-1:123456789012:vault:aBackupVault.
        iam_role_arn(str): Specifies the IAM role ARN used to copy the target recovery point; for example, arn:aws:iam::123456789012:role/S3Access.
        idempotency_token(str, optional): A customer chosen string that can be used to distinguish between calls to StartCopyJob. Defaults to None.
        lifecycle(Dict, optional): Contains an array of Transition objects specifying how long in days before a recovery point transitions to cold storage or is deleted. Backups transitioned to cold storage must be stored in cold storage for a minimum of 90 days. Therefore, on the console, the “expire after days” setting must be 90 days greater than the “transition to cold after days” setting. The “transition to cold after days” setting cannot be changed after a backup has been transitioned to cold. Only Amazon EFS file system backups can be transitioned to cold storage. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.copy_job.start(
                ctx,
                recovery_point_arn=value,
                source_backup_vault_name=value,
                destination_backup_vault_arn=value,
                iam_role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.copy_job.start recovery_point_arn=value, source_backup_vault_name=value, destination_backup_vault_arn=value, iam_role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="start_copy_job",
        op_kwargs={
            "RecoveryPointArn": recovery_point_arn,
            "SourceBackupVaultName": source_backup_vault_name,
            "DestinationBackupVaultArn": destination_backup_vault_arn,
            "IamRoleArn": iam_role_arn,
            "IdempotencyToken": idempotency_token,
            "Lifecycle": lifecycle,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    domain_name: str,
    admin_contact: Dict = None,
    registrant_contact: Dict = None,
    tech_contact: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This operation updates the contact information for a particular domain. You must specify information for at least one contact: registrant, administrator, or technical. If the update is successful, this method returns an operation ID that you can use to track the progress and completion of the action. If the request is not completed successfully, the domain registrant will be notified by email.

    Args:
        domain_name(str): The name of the domain that you want to update contact information for.
        admin_contact(Dict, optional): Provides detailed contact information. Defaults to None.
        registrant_contact(Dict, optional): Provides detailed contact information. Defaults to None.
        tech_contact(Dict, optional): Provides detailed contact information. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.contact.init.update(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.contact.init.update domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="update_domain_contact",
        op_kwargs={
            "DomainName": domain_name,
            "AdminContact": admin_contact,
            "RegistrantContact": registrant_contact,
            "TechContact": tech_contact,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    configuration_aggregator_name: str,
    update_status: List = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns status information for sources within an aggregator. The status includes information about the last time AWS Config verified authorization between the source account and an aggregator account. In case of a failure, the status contains the related error code or message.

    Args:
        configuration_aggregator_name(str): The name of the configuration aggregator.
        update_status(List, optional): Filters the status type.   Valid value FAILED indicates errors while moving data.   Valid value SUCCEEDED indicates the data was successfully moved.   Valid value OUTDATED indicates the data is not the most recent.  . Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.
        limit(int, optional): The maximum number of AggregatorSourceStatus returned on each page. The default is maximum. If you specify 0, AWS Config uses the default. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.configuration.aggregator.source_status.describe(
                ctx, configuration_aggregator_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.configuration.aggregator.source_status.describe configuration_aggregator_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_configuration_aggregator_sources_status",
        op_kwargs={
            "ConfigurationAggregatorName": configuration_aggregator_name,
            "UpdateStatus": update_status,
            "NextToken": next_token,
            "Limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, name: str, principal_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Disables an account setting for a specified IAM user, IAM role, or the root user for an account.

    Args:
        name(str): The resource name for which to disable the account setting. If serviceLongArnFormat is specified, the ARN for your Amazon ECS services is affected. If taskLongArnFormat is specified, the ARN and resource ID for your Amazon ECS tasks is affected. If containerInstanceLongArnFormat is specified, the ARN and resource ID for your Amazon ECS container instances is affected. If awsvpcTrunking is specified, the ENI limit for your Amazon ECS container instances is affected.
        principal_arn(str, optional): The ARN of the principal, which can be an IAM user, IAM role, or the root user. If you specify the root user, it disables the account setting for all IAM users, IAM roles, and the root user of the account unless an IAM user or role explicitly overrides these settings. If this field is omitted, the setting is changed only for the authenticated user. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.account_setting.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.account_setting.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="delete_account_setting",
        op_kwargs={"name": name, "principalArn": principal_arn},
    )


async def list_all(
    hub,
    ctx,
    name: str = None,
    value: str = None,
    principal_arn: str = None,
    effective_settings: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the account settings for a specified principal.

    Args:
        name(str, optional): The name of the account setting you want to list the settings for. Defaults to None.
        value(str, optional): The value of the account settings with which to filter results. You must also specify an account setting name to use this parameter. Defaults to None.
        principal_arn(str, optional): The ARN of the principal, which can be an IAM user, IAM role, or the root user. If this field is omitted, the account settings are listed only for the authenticated user.  Federated users assume the account setting of the root user and can't have explicit account settings set for them. . Defaults to None.
        effective_settings(bool, optional): Specifies whether to return the effective settings. If true, the account settings for the root user or the default setting for the principalArn are returned. If false, the account settings for the principalArn are returned if they are set. Otherwise, no account settings are returned. Defaults to None.
        next_token(str, optional): The nextToken value returned from a ListAccountSettings request indicating that more results are available to fulfill the request and further calls will be needed. If maxResults was provided, it is possible the number of results to be fewer than maxResults.  This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        max_results(int, optional): The maximum number of account setting results returned by ListAccountSettings in paginated output. When this parameter is used, ListAccountSettings only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListAccountSettings request with the returned nextToken value. This value can be between 1 and 10. If this parameter is not used, then ListAccountSettings returns up to 10 results and a nextToken value if applicable. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.account_setting.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.account_setting.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="list_account_settings",
        op_kwargs={
            "name": name,
            "value": value,
            "principalArn": principal_arn,
            "effectiveSettings": effective_settings,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def put(hub, ctx, name: str, value: str, principal_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an account setting. Account settings are set on a per-Region basis. If you change the account setting for the root user, the default settings for all of the IAM users and roles for which no individual account setting has been specified are reset. For more information, see Account Settings in the Amazon Elastic Container Service Developer Guide. When serviceLongArnFormat, taskLongArnFormat, or containerInstanceLongArnFormat are specified, the Amazon Resource Name (ARN) and resource ID format of the resource type for a specified IAM user, IAM role, or the root user for an account is affected. The opt-in and opt-out account setting must be set for each Amazon ECS resource separately. The ARN and resource ID format of a resource will be defined by the opt-in status of the IAM user or role that created the resource. You must enable this setting to use Amazon ECS features such as resource tagging. When awsvpcTrunking is specified, the elastic network interface (ENI) limit for any new container instances that support the feature is changed. If awsvpcTrunking is enabled, any new container instances that support the feature are launched have the increased ENI limits available to them. For more information, see Elastic Network Interface Trunking in the Amazon Elastic Container Service Developer Guide. When containerInsights is specified, the default setting indicating whether CloudWatch Container Insights is enabled for your clusters is changed. If containerInsights is enabled, any new clusters that are created will have Container Insights enabled unless you disable it during cluster creation. For more information, see CloudWatch Container Insights in the Amazon Elastic Container Service Developer Guide.

    Args:
        name(str): The Amazon ECS resource name for which to modify the account setting. If serviceLongArnFormat is specified, the ARN for your Amazon ECS services is affected. If taskLongArnFormat is specified, the ARN and resource ID for your Amazon ECS tasks is affected. If containerInstanceLongArnFormat is specified, the ARN and resource ID for your Amazon ECS container instances is affected. If awsvpcTrunking is specified, the elastic network interface (ENI) limit for your Amazon ECS container instances is affected. If containerInsights is specified, the default setting for CloudWatch Container Insights for your clusters is affected.
        value(str): The account setting value for the specified principal ARN. Accepted values are enabled and disabled.
        principal_arn(str, optional): The ARN of the principal, which can be an IAM user, IAM role, or the root user. If you specify the root user, it modifies the account setting for all IAM users, IAM roles, and the root user of the account unless an IAM user or role explicitly overrides these settings. If this field is omitted, the setting is changed only for the authenticated user.  Federated users assume the account setting of the root user and can't have explicit account settings set for them. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.account_setting.init.put(ctx, name=value, value=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.account_setting.init.put name=value, value=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="put_account_setting",
        op_kwargs={"name": name, "value": value, "principalArn": principal_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def deregister(hub, ctx, target_group_arn: str, targets: List) -> Dict:
    r"""
    **Autogenerated function**

    Deregisters the specified targets from the specified target group. After the targets are deregistered, they no longer receive traffic from the load balancer.

    Args:
        target_group_arn(str): The Amazon Resource Name (ARN) of the target group.
        targets(List): The targets. If you specified a port override when you registered a target, you must specify both the target ID and the port when you deregister it.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.target.init.deregister(
                ctx, target_group_arn=value, targets=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.target.init.deregister target_group_arn=value, targets=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="deregister_targets",
        op_kwargs={"TargetGroupArn": target_group_arn, "Targets": targets},
    )


async def register(hub, ctx, target_group_arn: str, targets: List) -> Dict:
    r"""
    **Autogenerated function**

    Registers the specified targets with the specified target group. If the target is an EC2 instance, it must be in the running state when you register it. By default, the load balancer routes requests to registered targets using the protocol and port for the target group. Alternatively, you can override the port for a target when you register it. You can register each EC2 instance or IP address with the same target group multiple times using different ports. With a Network Load Balancer, you cannot register instances by instance ID if they have the following instance types: C1, CC1, CC2, CG1, CG2, CR1, CS1, G1, G2, HI1, HS1, M1, M2, M3, and T1. You can register instances of these types by IP address.

    Args:
        target_group_arn(str): The Amazon Resource Name (ARN) of the target group.
        targets(List): The targets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.target.init.register(
                ctx, target_group_arn=value, targets=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.target.init.register target_group_arn=value, targets=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="register_targets",
        op_kwargs={"TargetGroupArn": target_group_arn, "Targets": targets},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def allocate(
    hub,
    ctx,
    connection_id: str,
    owner_account: str,
    new_public_virtual_interface_allocation: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Provisions a public virtual interface to be owned by the specified account. The owner of a connection calls this function to provision a public virtual interface to be owned by the specified account. Virtual interfaces created using this function must be confirmed by the owner using ConfirmPublicVirtualInterface. Until this step has been completed, the virtual interface is in the confirming state and is not available to handle traffic. When creating an IPv6 public virtual interface, omit the Amazon address and customer address. IPv6 addresses are automatically assigned from the Amazon pool of IPv6 addresses; you cannot specify custom IPv6 addresses.

    Args:
        connection_id(str): The ID of the connection on which the public virtual interface is provisioned.
        owner_account(str): The ID of the account that owns the public virtual interface.
        new_public_virtual_interface_allocation(Dict): Information about the public virtual interface.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.public_virtual_interface.allocate(
                ctx,
                connection_id=value,
                owner_account=value,
                new_public_virtual_interface_allocation=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.public_virtual_interface.allocate connection_id=value, owner_account=value, new_public_virtual_interface_allocation=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="allocate_public_virtual_interface",
        op_kwargs={
            "connectionId": connection_id,
            "ownerAccount": owner_account,
            "newPublicVirtualInterfaceAllocation": new_public_virtual_interface_allocation,
        },
    )


async def confirm(hub, ctx, virtual_interface_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Accepts ownership of a public virtual interface created by another account. After the virtual interface owner makes this call, the specified virtual interface is created and made available to handle traffic.

    Args:
        virtual_interface_id(str): The ID of the virtual interface.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.public_virtual_interface.confirm(
                ctx, virtual_interface_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.public_virtual_interface.confirm virtual_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="confirm_public_virtual_interface",
        op_kwargs={"virtualInterfaceId": virtual_interface_id},
    )


async def create(
    hub, ctx, connection_id: str, new_public_virtual_interface: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a public virtual interface. A virtual interface is the VLAN that transports Direct Connect traffic. A public virtual interface supports sending traffic to public services of Amazon Web Services such as Amazon S3. When creating an IPv6 public virtual interface (addressFamily is ipv6), leave the customer and amazon address fields blank to use auto-assigned IPv6 space. Custom IPv6 addresses are not supported.

    Args:
        connection_id(str): The ID of the connection.
        new_public_virtual_interface(Dict): Information about the public virtual interface.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.public_virtual_interface.create(
                ctx, connection_id=value, new_public_virtual_interface=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.public_virtual_interface.create connection_id=value, new_public_virtual_interface=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="create_public_virtual_interface",
        op_kwargs={
            "connectionId": connection_id,
            "newPublicVirtualInterface": new_public_virtual_interface,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    window_id: str,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the tasks in a maintenance window.  For maintenance window tasks without a specified target, you can't supply values for --max-errors and --max-concurrency. Instead, the system inserts a placeholder value of 1, which may be reported in the response to this command. These values don't affect the running of your task and can be ignored.

    Args:
        window_id(str): The ID of the maintenance window whose tasks should be retrieved.
        filters(List, optional): Optional filters used to narrow down the scope of the returned tasks. The supported filter keys are WindowTaskId, TaskArn, Priority, and TaskType. Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.task.describe_all(ctx, window_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.task.describe_all window_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_maintenance_window_tasks",
        op_kwargs={
            "WindowId": window_id,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def get(hub, ctx, window_id: str, window_task_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists the tasks in a maintenance window.  For maintenance window tasks without a specified target, you can't supply values for --max-errors and --max-concurrency. Instead, the system inserts a placeholder value of 1, which may be reported in the response to this command. These values don't affect the running of your task and can be ignored.

    Args:
        window_id(str): The maintenance window ID that includes the task to retrieve.
        window_task_id(str): The maintenance window task ID to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.task.get(
                ctx, window_id=value, window_task_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.task.get window_id=value, window_task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_maintenance_window_task",
        op_kwargs={"WindowId": window_id, "WindowTaskId": window_task_id},
    )


async def update(
    hub,
    ctx,
    window_id: str,
    window_task_id: str,
    targets: List = None,
    task_arn: str = None,
    service_role_arn: str = None,
    task_parameters: Dict = None,
    task_invocation_parameters: Dict = None,
    priority: int = None,
    max_concurrency: str = None,
    max_errors: str = None,
    logging_info: Dict = None,
    name: str = None,
    description: str = None,
    replace: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies a task assigned to a maintenance window. You can't change the task type, but you can change the following values:    TaskARN. For example, you can change a RUN_COMMAND task from AWS-RunPowerShellScript to AWS-RunShellScript.    ServiceRoleArn     TaskInvocationParameters     Priority     MaxConcurrency     MaxErrors     One or more targets must be specified for maintenance window Run Command-type tasks. Depending on the task, targets are optional for other maintenance window task types (Automation, Lambda, and Step Functions). For more information about running tasks that don't specify targets, see Registering maintenance window tasks without targets in the Amazon Web Services Systems Manager User Guide.  If the value for a parameter in UpdateMaintenanceWindowTask is null, then the corresponding field isn't modified. If you set Replace to true, then all fields required by the RegisterTaskWithMaintenanceWindow operation are required for this request. Optional fields that aren't specified are set to null.  When you update a maintenance window task that has options specified in TaskInvocationParameters, you must provide again all the TaskInvocationParameters values that you want to retain. The values you don't specify again are removed. For example, suppose that when you registered a Run Command task, you specified TaskInvocationParameters values for Comment, NotificationConfig, and OutputS3BucketName. If you update the maintenance window task and specify only a different OutputS3BucketName value, the values for Comment and NotificationConfig are removed.

    Args:
        window_id(str): The maintenance window ID that contains the task to modify.
        window_task_id(str): The task ID to modify.
        targets(List, optional): The targets (either instances or tags) to modify. Instances are specified using the format Key=instanceids,Values=instanceID_1,instanceID_2. Tags are specified using the format  Key=tag_name,Values=tag_value.   One or more targets must be specified for maintenance window Run Command-type tasks. Depending on the task, targets are optional for other maintenance window task types (Automation, Lambda, and Step Functions). For more information about running tasks that don't specify targets, see Registering maintenance window tasks without targets in the Amazon Web Services Systems Manager User Guide. . Defaults to None.
        task_arn(str, optional): The task ARN to modify. Defaults to None.
        service_role_arn(str, optional): The Amazon Resource Name (ARN) of the IAM service role for Amazon Web Services Systems Manager to assume when running a maintenance window task. If you do not specify a service role ARN, Systems Manager uses your account's service-linked role. If no service-linked role for Systems Manager exists in your account, it is created when you run RegisterTaskWithMaintenanceWindow. For more information, see the following topics in the in the Amazon Web Services Systems Manager User Guide:    Using service-linked roles for Systems Manager     Should I use a service-linked role or a custom service role to run maintenance window tasks?    . Defaults to None.
        task_parameters(Dict, optional): The parameters to modify.   TaskParameters has been deprecated. To specify parameters to pass to a task when it runs, instead use the Parameters option in the TaskInvocationParameters structure. For information about how Systems Manager handles these options for the supported maintenance window task types, see MaintenanceWindowTaskInvocationParameters.  The map has the following format: Key: string, between 1 and 255 characters Value: an array of strings, each string is between 1 and 255 characters. Defaults to None.
        task_invocation_parameters(Dict, optional): The parameters that the task should use during execution. Populate only the fields that match the task type. All other fields should be empty.  When you update a maintenance window task that has options specified in TaskInvocationParameters, you must provide again all the TaskInvocationParameters values that you want to retain. The values you don't specify again are removed. For example, suppose that when you registered a Run Command task, you specified TaskInvocationParameters values for Comment, NotificationConfig, and OutputS3BucketName. If you update the maintenance window task and specify only a different OutputS3BucketName value, the values for Comment and NotificationConfig are removed. . Defaults to None.
        priority(int, optional): The new task priority to specify. The lower the number, the higher the priority. Tasks that have the same priority are scheduled in parallel. Defaults to None.
        max_concurrency(str, optional): The new MaxConcurrency value you want to specify. MaxConcurrency is the number of targets that are allowed to run this task in parallel.  For maintenance window tasks without a target specified, you can't supply a value for this option. Instead, the system inserts a placeholder value of 1, which may be reported in the response to this command. This value doesn't affect the running of your task and can be ignored. . Defaults to None.
        max_errors(str, optional): The new MaxErrors value to specify. MaxErrors is the maximum number of errors that are allowed before the task stops being scheduled.  For maintenance window tasks without a target specified, you can't supply a value for this option. Instead, the system inserts a placeholder value of 1, which may be reported in the response to this command. This value doesn't affect the running of your task and can be ignored. . Defaults to None.
        logging_info(Dict, optional): The new logging location in Amazon S3 to specify.   LoggingInfo has been deprecated. To specify an Amazon Simple Storage Service (Amazon S3) bucket to contain logs, instead use the OutputS3BucketName and OutputS3KeyPrefix options in the TaskInvocationParameters structure. For information about how Amazon Web Services Systems Manager handles these options for the supported maintenance window task types, see MaintenanceWindowTaskInvocationParameters. . Defaults to None.
        name(str, optional): The new task name to specify. Defaults to None.
        description(str, optional): The new task description to specify. Defaults to None.
        replace(bool, optional): If True, then all fields that are required by the RegisterTaskWithMaintenanceWindow operation are also required for this API request. Optional fields that aren't specified are set to null. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.task.update(
                ctx, window_id=value, window_task_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.task.update window_id=value, window_task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="update_maintenance_window_task",
        op_kwargs={
            "WindowId": window_id,
            "WindowTaskId": window_task_id,
            "Targets": targets,
            "TaskArn": task_arn,
            "ServiceRoleArn": service_role_arn,
            "TaskParameters": task_parameters,
            "TaskInvocationParameters": task_invocation_parameters,
            "Priority": priority,
            "MaxConcurrency": max_concurrency,
            "MaxErrors": max_errors,
            "LoggingInfo": logging_info,
            "Name": name,
            "Description": description,
            "Replace": replace,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Applies the specified tags to the specified Amazon Chime SDK meeting resource.

    Args:
        resource_arn(str): The resource ARN.
        tags(List): The tag key-value pairs.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Untags the specified tags from the specified Amazon Chime SDK meeting resource.

    Args:
        resource_arn(str): The resource ARN.
        tag_keys(List): The tag keys.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, api_id: str, description: str = None, expires: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a unique key that you can distribute to clients who are executing your API.

    Args:
        api_id(str): The ID for your GraphQL API.
        description(str, optional): A description of the purpose of the API key. Defaults to None.
        expires(int, optional): The time from creation time after which the API key expires. The date is represented as seconds since the epoch, rounded down to the nearest hour. The default value for this parameter is 7 days from creation time. For more information, see . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.api.key.create(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.api.key.create api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="create_api_key",
        op_kwargs={"apiId": api_id, "description": description, "expires": expires},
    )


async def delete(hub, ctx, api_id: str, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an API key.

    Args:
        api_id(str): The API ID.
        id_(str): The ID for the API key.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.api.key.delete(ctx, api_id=value, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.api.key.delete api_id=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="delete_api_key",
        op_kwargs={"apiId": api_id, "id": id_},
    )


async def list_all(
    hub, ctx, api_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the API keys for a given API.  API keys are deleted automatically 60 days after they expire. However, they may still be included in the response until they have actually been deleted. You can safely call DeleteApiKey to manually delete a key before it's automatically deleted.

    Args:
        api_id(str): The API ID.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.
        max_results(int, optional): The maximum number of results you want the request to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.api.key.list_all(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.api.key.list_all api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="list_api_keys",
        op_kwargs={"apiId": api_id, "nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub, ctx, api_id: str, id_: str, description: str = None, expires: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an API key. The key can be updated while it is not deleted.

    Args:
        api_id(str): The ID for the GraphQL API.
        id_(str): The API key ID.
        description(str, optional): A description of the purpose of the API key. Defaults to None.
        expires(int, optional): The time from update time after which the API key expires. The date is represented as seconds since the epoch. For more information, see . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.api.key.update(ctx, api_id=value, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.api.key.update api_id=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="update_api_key",
        op_kwargs={
            "apiId": api_id,
            "id": id_,
            "description": description,
            "expires": expires,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(
    hub,
    ctx,
    resource_ids: List,
    resource_type: str,
    traffic_type: str,
    dry_run: bool = None,
    client_token: str = None,
    deliver_logs_permission_arn: str = None,
    log_group_name: str = None,
    log_destination_type: str = None,
    log_destination: str = None,
    log_format: str = None,
    tag_specifications: List = None,
    max_aggregation_interval: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates one or more flow logs to capture information about IP traffic for a specific network interface, subnet, or VPC.  Flow log data for a monitored network interface is recorded as flow log records, which are log events consisting of fields that describe the traffic flow. For more information, see Flow log records in the Amazon Virtual Private Cloud User Guide. When publishing to CloudWatch Logs, flow log records are published to a log group, and each network interface has a unique log stream in the log group. When publishing to Amazon S3, flow log records for all of the monitored network interfaces are published to a single log file object that is stored in the specified bucket. For more information, see VPC Flow Logs in the Amazon Virtual Private Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency. Defaults to None.
        deliver_logs_permission_arn(str, optional): The ARN for the IAM role that permits Amazon EC2 to publish flow logs to a CloudWatch Logs log group in your account. If you specify LogDestinationType as s3, do not specify DeliverLogsPermissionArn or LogGroupName. Defaults to None.
        log_group_name(str, optional): The name of a new or existing CloudWatch Logs log group where Amazon EC2 publishes your flow logs. If you specify LogDestinationType as s3, do not specify DeliverLogsPermissionArn or LogGroupName. Defaults to None.
        resource_ids(List): The ID of the subnet, network interface, or VPC for which you want to create a flow log. Constraints: Maximum of 1000 resources.
        resource_type(str): The type of resource for which to create the flow log. For example, if you specified a VPC ID for the ResourceId property, specify VPC for this property.
        traffic_type(str): The type of traffic to log. You can log traffic that the resource accepts or rejects, or all traffic.
        log_destination_type(str, optional): Specifies the type of destination to which the flow log data is to be published. Flow log data can be published to CloudWatch Logs or Amazon S3. To publish flow log data to CloudWatch Logs, specify cloud-watch-logs. To publish flow log data to Amazon S3, specify s3. If you specify LogDestinationType as s3, do not specify DeliverLogsPermissionArn or LogGroupName. Default: cloud-watch-logs . Defaults to None.
        log_destination(str, optional): Specifies the destination to which the flow log data is to be published. Flow log data can be published to a CloudWatch Logs log group or an Amazon S3 bucket. The value specified for this parameter depends on the value specified for LogDestinationType. If LogDestinationType is not specified or cloud-watch-logs, specify the Amazon Resource Name (ARN) of the CloudWatch Logs log group. For example, to publish to a log group called my-logs, specify arn:aws:logs:us-east-1:123456789012:log-group:my-logs. Alternatively, use LogGroupName instead. If LogDestinationType is s3, specify the ARN of the Amazon S3 bucket. You can also specify a subfolder in the bucket. To specify a subfolder in the bucket, use the following ARN format: bucket_ARN/subfolder_name/. For example, to specify a subfolder named my-logs in a bucket named my-bucket, use the following ARN: arn:aws:s3:::my-bucket/my-logs/. You cannot use AWSLogs as a subfolder name. This is a reserved term. Defaults to None.
        log_format(str, optional): The fields to include in the flow log record, in the order in which they should appear. For a list of available fields, see Flow log records. If you omit this parameter, the flow log is created using the default format. If you specify this parameter, you must specify at least one field. Specify the fields using the ${field-id} format, separated by spaces. For the CLI, use single quotation marks (' ') to surround the parameter value. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the flow logs. Defaults to None.
        max_aggregation_interval(int, optional): The maximum interval of time during which a flow of packets is captured and aggregated into a flow log record. You can specify 60 seconds (1 minute) or 600 seconds (10 minutes). When a network interface is attached to a Nitro-based instance, the aggregation interval is always 60 seconds or less, regardless of the value that you specify. Default: 600. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.flow_log.create_multiple(
                ctx, resource_ids=value, resource_type=value, traffic_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.flow_log.create_multiple resource_ids=value, resource_type=value, traffic_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_flow_logs",
        op_kwargs={
            "DryRun": dry_run,
            "ClientToken": client_token,
            "DeliverLogsPermissionArn": deliver_logs_permission_arn,
            "LogGroupName": log_group_name,
            "ResourceIds": resource_ids,
            "ResourceType": resource_type,
            "TrafficType": traffic_type,
            "LogDestinationType": log_destination_type,
            "LogDestination": log_destination,
            "LogFormat": log_format,
            "TagSpecifications": tag_specifications,
            "MaxAggregationInterval": max_aggregation_interval,
        },
    )


async def delete_multiple(hub, ctx, flow_log_ids: List, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes one or more flow logs.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        flow_log_ids(List): One or more flow log IDs. Constraint: Maximum of 1000 flow log IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.flow_log.delete_multiple(ctx, flow_log_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.flow_log.delete_multiple flow_log_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_flow_logs",
        op_kwargs={"DryRun": dry_run, "FlowLogIds": flow_log_ids},
    )


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    filter_: List = None,
    flow_log_ids: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more flow logs. To view the information in your flow logs (the log streams for the network interfaces), you must use the CloudWatch Logs console or the CloudWatch Logs API.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filter_(List, optional): One or more filters.    deliver-log-status - The status of the logs delivery (SUCCESS | FAILED).    log-destination-type - The type of destination to which the flow log publishes data. Possible destination types include cloud-watch-logs and s3.    flow-log-id - The ID of the flow log.    log-group-name - The name of the log group.    resource-id - The ID of the VPC, subnet, or network interface.    traffic-type - The type of traffic (ACCEPT | REJECT | ALL).    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.
        flow_log_ids(List, optional): One or more flow log IDs. Constraint: Maximum of 1000 flow log IDs. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.flow_log.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.flow_log.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_flow_logs",
        op_kwargs={
            "DryRun": dry_run,
            "Filter": filter_,
            "FlowLogIds": flow_log_ids,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    dataset_group_name: str,
    domain: str,
    dataset_arns: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a dataset group, which holds a collection of related datasets. You can add datasets to the dataset group when you create the dataset group, or later by using the UpdateDatasetGroup operation. After creating a dataset group and adding datasets, you use the dataset group when you create a predictor. For more information, see howitworks-datasets-groups. To get a list of all your datasets groups, use the ListDatasetGroups operation.  The Status of a dataset group must be ACTIVE before you can use the dataset group to create a predictor. To get the status, use the DescribeDatasetGroup operation.

    Args:
        dataset_group_name(str): A name for the dataset group.
        domain(str): The domain associated with the dataset group. When you add a dataset to a dataset group, this value and the value specified for the Domain parameter of the CreateDataset operation must match. The Domain and DatasetType that you choose determine the fields that must be present in training data that you import to a dataset. For example, if you choose the RETAIL domain and TARGET_TIME_SERIES as the DatasetType, Amazon Forecast requires that item_id, timestamp, and demand fields are present in your data. For more information, see howitworks-datasets-groups.
        dataset_arns(List, optional): An array of Amazon Resource Names (ARNs) of the datasets that you want to include in the dataset group. Defaults to None.
        tags(List, optional): The optional metadata that you apply to the dataset group to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50.   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8.   Maximum value length - 256 Unicode characters in UTF-8.   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Forecast considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.dataset.group.create(
                ctx, dataset_group_name=value, domain=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.dataset.group.create dataset_group_name=value, domain=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="create_dataset_group",
        op_kwargs={
            "DatasetGroupName": dataset_group_name,
            "Domain": domain,
            "DatasetArns": dataset_arns,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, dataset_group_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a dataset group created using the CreateDatasetGroup operation. You can only delete dataset groups that have a status of ACTIVE, CREATE_FAILED, or UPDATE_FAILED. To get the status, use the DescribeDatasetGroup operation. This operation deletes only the dataset group, not the datasets in the group.

    Args:
        dataset_group_arn(str): The Amazon Resource Name (ARN) of the dataset group to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.dataset.group.delete(ctx, dataset_group_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.dataset.group.delete dataset_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="delete_dataset_group",
        op_kwargs={"DatasetGroupArn": dataset_group_arn},
    )


async def describe(hub, ctx, dataset_group_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a dataset group created using the CreateDatasetGroup operation. In addition to listing the parameters provided in the CreateDatasetGroup request, this operation includes the following properties:    DatasetArns - The datasets belonging to the group.    CreationTime     LastModificationTime     Status

    Args:
        dataset_group_arn(str): The Amazon Resource Name (ARN) of the dataset group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.dataset.group.describe(ctx, dataset_group_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.dataset.group.describe dataset_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="describe_dataset_group",
        op_kwargs={"DatasetGroupArn": dataset_group_arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of dataset groups created using the CreateDatasetGroup operation. For each dataset group, this operation returns a summary of its properties, including its Amazon Resource Name (ARN). You can retrieve the complete set of properties by using the dataset group ARN with the DescribeDatasetGroup operation.

    Args:
        next_token(str, optional): If the result of the previous request was truncated, the response includes a NextToken. To retrieve the next set of results, use the token in the next request. Tokens expire after 24 hours. Defaults to None.
        max_results(int, optional): The number of items to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.dataset.group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.dataset.group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="list_dataset_groups",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(hub, ctx, dataset_group_arn: str, dataset_arns: List) -> Dict:
    r"""
    **Autogenerated function**

    Replaces the datasets in a dataset group with the specified datasets.  The Status of the dataset group must be ACTIVE before you can use the dataset group to create a predictor. Use the DescribeDatasetGroup operation to get the status.

    Args:
        dataset_group_arn(str): The ARN of the dataset group.
        dataset_arns(List): An array of the Amazon Resource Names (ARNs) of the datasets to add to the dataset group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.dataset.group.update(
                ctx, dataset_group_arn=value, dataset_arns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.dataset.group.update dataset_group_arn=value, dataset_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="update_dataset_group",
        op_kwargs={"DatasetGroupArn": dataset_group_arn, "DatasetArns": dataset_arns},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Retrieves all tags that are assigned to a GameLift resource. Resource tags are used to organize AWS resources for a range of purposes. This operation handles the permissions necessary to manage tags for the following GameLift resource types:   Build   Script   Fleet   Alias   GameSessionQueue   MatchmakingConfiguration   MatchmakingRuleSet   To list tags for a resource, specify the unique ARN value for the resource.  Learn more   Tagging AWS Resources in the AWS General Reference    AWS Tagging Strategies   Related actions   TagResource | UntagResource | ListTagsForResource | All APIs by task

    Args:
        resource_arn(str):  The Amazon Resource Name (ARN) that is assigned to and uniquely identifies the GameLift resource that you want to retrieve tags for. GameLift resource ARNs are included in the data object for the resource, which can be retrieved by calling a List or Describe operation for the resource type. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceARN": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Permanently cancel a job. Once you have canceled a job, you can't start it again.

    Args:
        id_(str): The Job ID of the job to be cancelled.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.job.init.cancel(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.job.init.cancel id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="mediaconvert", operation="cancel_job", op_kwargs={"Id": id_}
    )


async def create(
    hub,
    ctx,
    role: str,
    settings: Dict,
    acceleration_settings: Dict = None,
    billing_tags_source: str = None,
    client_request_token: str = None,
    hop_destinations: List = None,
    job_template: str = None,
    priority: int = None,
    queue: str = None,
    simulate_reserved_queue: str = None,
    status_update_interval: str = None,
    tags: Dict = None,
    user_metadata: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new transcoding job. For information about jobs and job settings, see the User Guide at http://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html

    Args:
        acceleration_settings(Dict, optional): Optional. Accelerated transcoding can significantly speed up jobs with long, visually complex content. Outputs that use this feature incur pro-tier pricing. For information about feature limitations, see the AWS Elemental MediaConvert User Guide. Defaults to None.
        billing_tags_source(str, optional): Optional. Choose a tag type that AWS Billing and Cost Management will use to sort your AWS Elemental MediaConvert costs on any billing report that you set up. Any transcoding outputs that don't have an associated tag will appear in your billing report unsorted. If you don't choose a valid value for this field, your job outputs will appear on the billing report unsorted. Defaults to None.
        client_request_token(str, optional): Optional. Idempotency token for CreateJob operation. Defaults to None.
        hop_destinations(List, optional): Optional. Use queue hopping to avoid overly long waits in the backlog of the queue that you submit your job to. Specify an alternate queue and the maximum time that your job will wait in the initial queue before hopping. For more information about this feature, see the AWS Elemental MediaConvert User Guide. Defaults to None.
        job_template(str, optional): Optional. When you create a job, you can either specify a job template or specify the transcoding settings individually. Defaults to None.
        priority(int, optional): Optional. Specify the relative priority for this job. In any given queue, the service begins processing the job with the highest value first. When more than one job has the same priority, the service begins processing the job that you submitted first. If you don't specify a priority, the service uses the default value 0. Defaults to None.
        queue(str, optional): Optional. When you create a job, you can specify a queue to send it to. If you don't specify, the job will go to the default queue. For more about queues, see the User Guide topic at https://docs.aws.amazon.com/mediaconvert/latest/ug/what-is.html. Defaults to None.
        role(str): Required. The IAM role you use for creating this job. For details about permissions, see the User Guide topic at the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/iam-role.html.
        settings(Dict): JobSettings contains all the transcode settings for a job.
        simulate_reserved_queue(str, optional): Optional. Enable this setting when you run a test job to estimate how many reserved transcoding slots (RTS) you need. When this is enabled, MediaConvert runs your job from an on-demand queue with similar performance to what you will see with one RTS in a reserved queue. This setting is disabled by default. Defaults to None.
        status_update_interval(str, optional): Optional. Specify how often MediaConvert sends STATUS_UPDATE events to Amazon CloudWatch Events. Set the interval, in seconds, between status updates. MediaConvert sends an update at this interval from the time the service begins processing your job to the time it completes the transcode or encounters an error. Defaults to None.
        tags(Dict, optional): Optional. The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key.  Use standard AWS tags on your job for automatic integration with AWS services and for custom integrations and workflows. Defaults to None.
        user_metadata(Dict, optional): Optional. User-defined metadata that you want to associate with an MediaConvert job. You specify metadata in key/value pairs.  Use only for existing integrations or workflows that rely on job metadata tags. Otherwise, we recommend that you use standard AWS tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.job.init.create(ctx, role=value, settings=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.job.init.create role=value, settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="create_job",
        op_kwargs={
            "AccelerationSettings": acceleration_settings,
            "BillingTagsSource": billing_tags_source,
            "ClientRequestToken": client_request_token,
            "HopDestinations": hop_destinations,
            "JobTemplate": job_template,
            "Priority": priority,
            "Queue": queue,
            "Role": role,
            "Settings": settings,
            "SimulateReservedQueue": simulate_reserved_queue,
            "StatusUpdateInterval": status_update_interval,
            "Tags": tags,
            "UserMetadata": user_metadata,
        },
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve the JSON for a specific completed transcoding job.

    Args:
        id_(str): the job ID of the job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.job.init.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.job.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="mediaconvert", operation="get_job", op_kwargs={"Id": id_}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def confirm(hub, ctx, connection_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Confirms the creation of the specified hosted connection on an interconnect. Upon creation, the hosted connection is initially in the Ordering state, and remains in this state until the owner confirms creation of the hosted connection.

    Args:
        connection_id(str): The ID of the hosted connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.connection.init.confirm(ctx, connection_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.connection.init.confirm connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="confirm_connection",
        op_kwargs={"connectionId": connection_id},
    )


async def create(
    hub,
    ctx,
    location: str,
    bandwidth: str,
    connection_name: str,
    lag_id: str = None,
    tags: List = None,
    provider_name: str = None,
    request_mac_sec: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a connection between a customer network and a specific Direct Connect location. A connection links your internal network to an Direct Connect location over a standard Ethernet fiber-optic cable. One end of the cable is connected to your router, the other to an Direct Connect router. To find the locations for your Region, use DescribeLocations. You can automatically add the new connection to a link aggregation group (LAG) by specifying a LAG ID in the request. This ensures that the new connection is allocated on the same Direct Connect endpoint that hosts the specified LAG. If there are no available ports on the endpoint, the request fails and no connection is created.

    Args:
        location(str): The location of the connection.
        bandwidth(str): The bandwidth of the connection.
        connection_name(str): The name of the connection.
        lag_id(str, optional): The ID of the LAG. Defaults to None.
        tags(List, optional): The tags to associate with the lag. Defaults to None.
        provider_name(str, optional): The name of the service provider associated with the requested connection. Defaults to None.
        request_mac_sec(bool, optional): Indicates whether you want the connection to support MAC Security (MACsec). MAC Security (MACsec) is only available on dedicated connections. For information about MAC Security (MACsec) prerequisties, see MACsec prerequisties in the Direct Connect User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.connection.init.create(
                ctx, location=value, bandwidth=value, connection_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.connection.init.create location=value, bandwidth=value, connection_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="create_connection",
        op_kwargs={
            "location": location,
            "bandwidth": bandwidth,
            "connectionName": connection_name,
            "lagId": lag_id,
            "tags": tags,
            "providerName": provider_name,
            "requestMACSec": request_mac_sec,
        },
    )


async def delete(hub, ctx, connection_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified connection. Deleting a connection only stops the Direct Connect port hour and data transfer charges. If you are partnering with any third parties to connect with the Direct Connect location, you must cancel your service with them separately.

    Args:
        connection_id(str): The ID of the connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.connection.init.delete(ctx, connection_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.connection.init.delete connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="delete_connection",
        op_kwargs={"connectionId": connection_id},
    )


async def describe_all(hub, ctx, connection_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Displays the specified connection or all connections in this Region.

    Args:
        connection_id(str, optional): The ID of the connection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.connection.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.connection.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="describe_connections",
        op_kwargs={"connectionId": connection_id},
    )


async def update(
    hub,
    ctx,
    connection_id: str,
    connection_name: str = None,
    encryption_mode: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the Direct Connect dedicated connection configuration. You can update the following parameters for a connection:   The connection name   The connection's MAC Security (MACsec) encryption mode.

    Args:
        connection_id(str): The ID of the dedicated connection. You can use DescribeConnections to retrieve the connection ID.
        connection_name(str, optional): The name of the connection. Defaults to None.
        encryption_mode(str, optional): The connection MAC Security (MACsec) encryption mode. The valid values are no_encrypt, should_encrypt, and must_encrypt. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.connection.init.update(ctx, connection_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.connection.init.update connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="update_connection",
        op_kwargs={
            "connectionId": connection_id,
            "connectionName": connection_name,
            "encryptionMode": encryption_mode,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub,
    ctx,
    type_name: str,
    schema_delete_option: str = None,
    dry_run: bool = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Delete a custom inventory type or the data associated with a custom Inventory type. Deleting a custom inventory type is also referred to as deleting a custom inventory schema.

    Args:
        type_name(str): The name of the custom inventory type for which you want to delete either all previously collected data or the inventory type itself. .
        schema_delete_option(str, optional): Use the SchemaDeleteOption to delete a custom inventory type (schema). If you don't choose this option, the system only deletes existing inventory data associated with the custom inventory type. Choose one of the following options: DisableSchema: If you choose this option, the system ignores all inventory data for the specified version, and any earlier versions. To enable this schema again, you must call the PutInventory operation for a version greater than the disabled version. DeleteSchema: This option deletes the specified custom type from the Inventory service. You can recreate the schema later, if you want. Defaults to None.
        dry_run(bool, optional): Use this option to view a summary of the deletion request without deleting any data or the data type. This option is useful when you only want to understand what will be deleted. Once you validate that the data to be deleted is what you intend to delete, you can run the same command without specifying the DryRun option. Defaults to None.
        client_token(str, optional): User-provided idempotency token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.inventory.init.delete(ctx, type_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.inventory.init.delete type_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="delete_inventory",
        op_kwargs={
            "TypeName": type_name,
            "SchemaDeleteOption": schema_delete_option,
            "DryRun": dry_run,
            "ClientToken": client_token,
        },
    )


async def get(
    hub,
    ctx,
    filters: List = None,
    aggregators: List = None,
    result_attributes: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Query inventory information.

    Args:
        filters(List, optional): One or more filters. Use a filter to return a more specific list of results. Defaults to None.
        aggregators(List, optional): Returns counts of inventory types based on one or more expressions. For example, if you aggregate by using an expression that uses the AWS:InstanceInformation.PlatformType type, you can see a count of how many Windows and Linux instances exist in your inventoried fleet. Defaults to None.
        result_attributes(List, optional): The list of inventory item types to return. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.inventory.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.inventory.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_inventory",
        op_kwargs={
            "Filters": filters,
            "Aggregators": aggregators,
            "ResultAttributes": result_attributes,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def put(hub, ctx, instance_id: str, items: List) -> Dict:
    r"""
    **Autogenerated function**

    Bulk update custom inventory items on one more instance. The request adds an inventory item, if it doesn't already exist, or updates an inventory item, if it does exist.

    Args:
        instance_id(str): An instance ID where you want to add or update inventory items.
        items(List): The inventory items that you want to add or update on instances.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.inventory.init.put(ctx, instance_id=value, items=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.inventory.init.put instance_id=value, items=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="put_inventory",
        op_kwargs={"InstanceId": instance_id, "Items": items},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    start_time_in_seconds: int,
    end_time_in_seconds: int,
    quality: str,
    interval_in_seconds: int,
    type_: str,
    asset_id: str = None,
    property_id: str = None,
    property_alias: str = None,
    start_time_offset_in_nanos: int = None,
    end_time_offset_in_nanos: int = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Get interpolated values for an asset property for a specified time interval, during a period of time. For example, you can use the this operation to return the interpolated temperature values for a wind turbine every 24 hours over a duration of 7 days. To identify an asset property, you must specify one of the following:   The assetId and propertyId of an asset property.   A propertyAlias, which is a data stream alias (for example, /company/windfarm/3/turbine/7/temperature). To define an asset property's alias, see UpdateAssetProperty.

    Args:
        asset_id(str, optional): The ID of the asset. Defaults to None.
        property_id(str, optional): The ID of the asset property. Defaults to None.
        property_alias(str, optional): The alias that identifies the property, such as an OPC-UA server data stream path (for example, /company/windfarm/3/turbine/7/temperature). For more information, see Mapping industrial data streams to asset properties in the IoT SiteWise User Guide. Defaults to None.
        start_time_in_seconds(int): The exclusive start of the range from which to interpolate data, expressed in seconds in Unix epoch time.
        start_time_offset_in_nanos(int, optional): The nanosecond offset converted from startTimeInSeconds. Defaults to None.
        end_time_in_seconds(int): The inclusive end of the range from which to interpolate data, expressed in seconds in Unix epoch time.
        end_time_offset_in_nanos(int, optional): The nanosecond offset converted from endTimeInSeconds. Defaults to None.
        quality(str): The quality of the asset property value. You can use this parameter as a filter to choose only the asset property values that have a specific quality.
        interval_in_seconds(int): The time interval in seconds over which to interpolate data. Each interval starts when the previous one ends.
        next_token(str, optional): The token to be used for the next set of paginated results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for each paginated request. If not specified, the default value is 10. Defaults to None.
        type_(str): The interpolation type. Valid values: LINEAR_INTERPOLATION .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.interpolated_asset_property_value.get_all(
                ctx,
                start_time_in_seconds=value,
                end_time_in_seconds=value,
                quality=value,
                interval_in_seconds=value,
                type_=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.interpolated_asset_property_value.get_all start_time_in_seconds=value, end_time_in_seconds=value, quality=value, interval_in_seconds=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="get_interpolated_asset_property_values",
        op_kwargs={
            "assetId": asset_id,
            "propertyId": property_id,
            "propertyAlias": property_alias,
            "startTimeInSeconds": start_time_in_seconds,
            "startTimeOffsetInNanos": start_time_offset_in_nanos,
            "endTimeInSeconds": end_time_in_seconds,
            "endTimeOffsetInNanos": end_time_offset_in_nanos,
            "quality": quality,
            "intervalInSeconds": interval_in_seconds,
            "nextToken": next_token,
            "maxResults": max_results,
            "type": type_,
        },
    )
